@@ -17,20 +17,30 @@
 
 # coding=utf-8
 
-import urllib
-import base64
-from Crypto.Signature import PKCS1_v1_5
-from Crypto.Hash import SHA256
-from Crypto.PublicKey import RSA
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric import padding
+from cryptography.hazmat.primitives.serialization import load_der_private_key
+
+from aliyunsdkcore.compat import ensure_string
+from aliyunsdkcore.compat import ensure_bytes
+from aliyunsdkcore.compat import b64_encode_bytes
+from aliyunsdkcore.compat import b64_decode_bytes
 
 
 def get_sign_string(source, access_secret):
-    secret = base64.decodestring(access_secret)
-    key = RSA.importKey(secret)
-    h = SHA256.new(source)
-    signer = PKCS1_v1_5.new(key)
-    signed_bytes = signer.sign(h)
-    signature = base64.encodestring(signed_bytes).replace('\n', '')
+    key = load_der_private_key(
+        b64_decode_bytes(ensure_bytes(access_secret)),
+        password=None,
+        backend=default_backend()
+    )
+    signed_bytes = key.sign(
+        ensure_bytes(source),
+        padding.PKCS1v15(),
+        hashes.SHA256()
+    )
+    signed_base64 = b64_encode_bytes(signed_bytes)
+    signature = ensure_string(signed_base64).replace('\n', '')
     return signature
 
 
@@ -38,7 +48,7 @@ def get_signer_name():
     return "SHA256withRSA"
 
 
-def get_singer_version():
+def get_signer_version():
     return "1.0"
 
 
